@@ -53,7 +53,7 @@ plot.lsjm <- function(x, Y, drawCB = FALSE, dimZ = c(1, 2), plotZtilde = FALSE,
 {		
 		stopifnot(inherits(x, 'lsjm'))
 		stopifnot(is.logical(drawCB) & length(drawCB) == 1)
-		stopifnot(dimZ %in% seq(1: ncol(x$EZ)) && length(dimZ == 2))
+		stopifnot(all(dimZ %in% seq(1: ncol(x$EZ))) && length(dimZ == 2))
 		stopifnot(is.logical(plotZtilde) & length(plotZtilde) == 1)
 	
 	if(plotZtilde){
